#ifndef _PILOT_VERSION_H_
#define _PILOT_VERSION_H_

#define PILOT_LINK_VERSION 0
#define PILOT_LINK_MAJOR 9
#define PILOT_LINK_MINOR 5

/* If releasing a version without a patch number, make sure that this is not
   defined, simply leave blank quotes. */

#define PILOT_LINK_PATCH ""
#endif				/* _PILOT_VERSION_H_ */
